#[non_exhaustive]pub enum Error {
Eof,
InvalidLength,
BadCast,
InvalidReadSize,
InvalidVbrWidth,
Short,
}Expand description
All errors potentially produced by llvm-bitcursor APIs.
Consumers should not attempt to match specific variants of this error type.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Eof
A read or other I/O operation encountered the end of the inner buffer.
InvalidLength
A user attempted to call BitCursor::new_with_len with
an impossible length (larger that the supplied buffer).
BadCast
A generic API (e.g. BitCursor::read_as) was asked to
read a value larger than the requested type could represent.
InvalidReadSize
A read API was called with an invalid bitsize (too small or large).
InvalidVbrWidth
A VBR read API was called with an invalid VBR width.
Short
An I/O operation completed partially, but the inner buffer ended before it full completion.